@@ -27,10 +27,13 @@ function(rank = NULL, rank.args = NULL, object = NULL, ...) {
 		return(IC)
 	} else if(inherits(rank, "rankFunction") && length(rank.args) == 0L) {
 		return(rank)
-	}
-
-	srank <- substitute(rank, parent.frame())
-	if(srank == "rank") srank <- substitute(rank)
+	} else if(is.list(rank) && length(rank) == 1L && is.function(rank[[1L]])) {
+        srank <- names(rank)[1L]
+        rank <- rank[[1L]]
+    } else {
+        srank <- substitute(rank, parent.frame())
+        if(srank == "rank") srank <- substitute(rank)
+    }
 
 	rank <- match.fun(rank)
 	ICName <- switch(mode(srank), call = as.name("IC"), character = as.name(srank), name=, srank)
@@ -51,59 +54,77 @@ function(rank = NULL, rank.args = NULL, object = NULL, ...) {
 }
 
 
+# Like `regmatches`, but for captured groups, and simplistic.
+# Only does results of `regexpr`.
+.matches <-
+function (x, m) { 
+	cs <- attr(m, "capture.start")
+	cl <- attr(m, "capture.length")
+	rval <- array(NA_character_, dim = dim(cs))
+	for(i in seq_along(x))
+		rval[i, ] <- substring(x[i], cs[i, ], cs[i, ] + cl[i, ] - 1L)
+	rval
+}
+
+
 # sorts alphabetically interaction components in model term names
 # if 'peel', tries to remove coefficients wrapped into function-like syntax
 # (this is meant mainly for 'unmarkedFit' models with names such as "psi(a:b:c)")
-# FIXME: this function is ugly
+# This unwrapping is done only if ALL names are suitable for it.
 `fixCoefNames` <-
 function(x, peel = TRUE) {
 	if(!length(x)) return(x)
-	ox <- x
 	ia <- grep(":", x, fixed = TRUE)
 	if(!length(ia)) return(structure(x, order = rep.int(1L, length(x))))
-	x <- ret <- x[ia]
+	
+	ixi <- x[ia]
 	if(peel) {
-		# case of pscl::hurdle, cf are prefixed with count_|zero_
-		if(all(substr(x, 1L, pos <- regexpr("_", x, fixed = TRUE)) %in%
-			c("count_", "zero_"))) {
-				ret <- substr(ret, pos + 1L, 256L)
-				k <- TRUE
-				suffix <- ""
-		} else { # unmarkedFit with its phi(...), lambda(...) etc...
-			k <- grepl("^\\w+\\(.+\\)$", x, perl = TRUE)
-			fname <- substring(x[k], 1L, attr(regexpr("^\\w+(?=\\()", x[k],
-				perl = TRUE),"match.length"))
-
-			# do not peel off if a function
-			k[k] <- !vapply(fname, exists, FALSE, mode = "function", envir = .GlobalEnv)
-			if(any(k)) {
-				pos <- vapply(x[k], function(z) {
-					parens <- lapply(lapply(c("(", ")"),
-						function(s) gregexpr(s, z, fixed = TRUE)[[1L]]),
-							function(y) y[y > 0L])
-					parseq <- unlist(parens, use.names = FALSE)
-					p <- cumsum(rep(c(1L, -1L), sapply(parens, length))[order(parseq)])
-					if(any(p[-length(p)] == 0L)) -1L else parseq[1L]
-				}, 1L, USE.NAMES = FALSE)
-				k[k] <- pos != -1L
-				pos <- pos[pos != -1]
-				if(any(k)) ret[k] <- substring(x[k], pos + 1L, nchar(x[k]) - 1L)
+		# peel only when ALL items are prefixed/wrapped
+		# for pscl::hurdle. Cf are prefixed with count_|zero_
+		if(peel <- all(startsWith(ixi, c("count_", "zero_")))) {
+			pos <- regexpr("_", ixi, fixed = TRUE)
+			peelpfx <- substring(ixi, 1L, pos)
+			peelsfx <- ""
+			ixi <- substring(ixi, pos + 1L)
+		} else {
+			# unmarkedFit with its phi(...), lambda(...) etc...
+			if(peel <- all(endsWith(ixi, ")"))) {
+				# only if 'XXX(...)', i.e. exclude 'XXX():YYY()' or such
+				m <- regexpr("^(([^()]*)\\(((?:[^()]*|(?1))*)\\))$", ixi, perl = TRUE, useBytes = TRUE)
+				cptgrps <- .matches(ixi, m)
+				if(peel <- all(cptgrps[, 2L] != "")) {
+					peelpfx <- paste0(cptgrps[, 2L], "(")
+					peelsfx <- ")"
+					ixi <- cptgrps[, 3L]
+				}
 			}
-			suffix <- ")"
 		}
-	} else	k <- FALSE
+	}
+	# replace {...}, [...], (...), ::, and ::: with placeholders
+	m <- gregexpr("(?:\\{(?:[^\\{\\}]*|(?0))*\\}|\\[(?:[^\\[\\]]*|(?0))*\\]|\\((?:[^()]*|(?0))*\\)|(?>:::?))", ixi, perl = TRUE)
+	xtpl <- ixi
+	regmatches(xtpl, m) <- lapply(m, function(x) {
+		if((ml <- attr(x, "match.length"))[1L] == -1L) return(character(0L))
+		sapply(ml, function(n) paste0(rep("_", n), collapse = ""))
+	})
+	
+	# split by ':' and sort
+	splits <- gregexpr(":", xtpl, fixed = TRUE)
+	ixi <- mapply(function(x, p) {
+		if(p[1L] == -1) return(x)
+		paste0(base::sort(substring(x, c(1L, p + 1L), c(p - 1L, nchar(x)))), collapse = ":")
+	}, ixi, splits, USE.NAMES = FALSE, SIMPLIFY = TRUE)
+	
+	if(peel) ixi <- paste0(peelpfx, ixi, peelsfx)
 
-	## prepare = replace multiple ':' to avoid splitting by '::' and ':::'
-	spl <- expr.split(ret, ":", prepare = function(x) gsub("((?<=:):|:(?=:))", "_", x, perl = TRUE))
-	ret <- vapply(lapply(spl, base::sort), paste0, "", collapse = ":")
-	if(peel && any(k))
-		ret[k] <- paste0(substring(x[k], 1L, pos), ret[k], suffix)
-	ox[ia] <- ret
-	ord <- rep.int(1, length(ox))
-	ord[ia] <- sapply(spl, length)
-	structure(ox, order = ord)
+	x[ia] <- ixi
+	ord <- rep.int(1L, length(x))
+	ord[ia] <- vapply(splits, length, 0L) + 1L
+	attr(x, "order") <- ord
+	x
 }
 
+
 ## like 'strsplit', but ignores split characters within quotes and matched
 ## parentheses
 expr.split <-
@@ -198,7 +219,8 @@ function(models, error = TRUE) {
 
 .checkNaAction <-
 function(x, cl = get_call(x),
-		 naomi = c("na.omit", "na.exclude"), what = "model") {
+		 naomi = c("na.omit", "na.exclude"), what = "model",
+		 envir = parent.frame()) {
 	naact <- NA_character_
 	msg <- NA_character_
 
@@ -208,7 +230,7 @@ function(x, cl = get_call(x),
 		if(is.symbol(x)) {
 			x <- as.character(x)
 		} else if(is.call(x)) {
-			x <- eval.parent(x, 2L)
+			x <- eval(x, envir)
 			if(is.symbol(x)) x <- as.character(x)
 		}
 		return(x)
@@ -217,20 +239,18 @@ function(x, cl = get_call(x),
 	#.checkNaAction(list(call = as.call(alist(fun, na.action = getOption("na.action", default = na.fail)))))
 	#.checkNaAction(list(call = as.call(alist(fun, na.action = na.fail))))
 	#.checkNaAction(list(call = as.call(alist(fun, na.action = na.omit))))
-
-
 	
 	if (!is.null(cl$na.action)) {
 		naact <- .getNAActionString(cl$na.action)
 		if (naact %in% naomi)
 			msg <- sprintf("%s uses 'na.action' = \"%s\"", what, naact)
 	} else {
-		naact <- formals(eval(cl[[1L]]))$na.action
+		naact <- formals(eval(cl[[1L]], envir))$na.action
 		if (missing(naact)) {
 			naact <- getOption("na.action")
 			if(is.function(naact)) {
 				statsNs <- getNamespace("stats")
-				for(i in naomi) if(identical(get(i, envir = statsNs), naact,
+				for(i in naomi) if(identical(get(i, envir = statsNs, inherits = FALSE), naact,
 					ignore.environment = TRUE)) {
 					naact <- i
 					break
@@ -276,7 +296,7 @@ function(x, minlength = 4, minwordlen = 1,
 	av <- v
 	if(length(i)) {
 		tb <- rbindDataFrameList(lapply(s, function(x)
-			as.data.frame(rbind(c(table(x))))))
+			as.data.frame(rbind(c(table(x))), stringsAsFactors = TRUE)))
 		tb[is.na(tb)] <- 0L
 
 		if(length(v) > length(i)) minlength <-
@@ -299,16 +319,19 @@ function(x, minlength = 4, minwordlen = 1,
 `modelDescr` <-
 function(models, withModel = FALSE, withFamily = TRUE,
 	withArguments = TRUE, remove.cols = c("formula", "random", "fixed", "model",
-	"data", "family", "cluster", "model.parameters")) {
+	"data", "family", "cluster", "model.parameters"),
+	remove.pattern = "formula$", ...) {
 
 	if(withModel) {
 		allTermsList <- lapply(models, function(x) {
 			tt <- getAllTerms(x)
 			rtt <- attr(tt, "random.terms")
-			c(tt, if(!is.null(rtt)) paste0("(", rtt, ")") else NULL)
+			if(!is.null(rtt))
+				rtt[i] <- paste0("(", rtt[i <- !grepl("^[a-z]*\\(.+\\)$", rtt)], ")")
+			c(tt, rtt)
 		})
 		allTerms <- unique(unlist(allTermsList))
-		abvtt <- abbreviateTerms(allTerms)
+		abvtt <- abbreviateTerms(allTerms, ...)
 		variables <- attr(abvtt, "variables")
 		abvtt <- gsub("\\(1 \\| (\\S+)(?: %in%.*)?\\)", "(\\1)", abvtt, perl = TRUE)
 		abvtt <- sapply(allTermsList, function(x) paste(abvtt[match(x, allTerms)],
@@ -343,6 +366,7 @@ function(models, withModel = FALSE, withFamily = TRUE,
 	}
 
 	if(withArguments) {
+		
 		cl <- lapply(models, get_call)
 		haveNoCall <-  vapply(cl, is.null, FALSE)
 		cl[haveNoCall] <- lapply(cl[haveNoCall], function(x) call("none", formula = NA))
@@ -350,8 +374,12 @@ function(models, withModel = FALSE, withFamily = TRUE,
 			switch(mode(argval), character = , logical = argval,
 			numeric = signif(argval, 3L), asChar(argval))))
 		arg <- rbindDataFrameList(lapply(lapply(arg, t), as.data.frame))
+		
+		i <- !(colnames(arg) %in% remove.cols)
+		i[i][grep(remove.pattern[1L], colnames(arg)[i])] <- FALSE
+
 		arg <- cbind(class = as.factor(sapply(lapply(models, class), "[", 1L)),
-			arg[, !(colnames(arg) %in% remove.cols), drop = FALSE])
+			arg[, i, drop = FALSE])
 		reml <-	rep(NA, length(models))
 		if(!is.null(arg$method)) {
 			reml <- ((arg$class == "lme" &
@@ -367,18 +395,36 @@ function(models, withModel = FALSE, withFamily = TRUE,
 		if(ncol(arg)) arg <- gsub("([\"'\\s]+|\\w+ *=)","", arg, perl = TRUE)
 	}
 	ret <- as.data.frame(cbind(model = abvtt, family = if(withFamily) fam else NULL,
-		arg, deparse.level = 0L))
+		arg, deparse.level = 0L), stringsAsFactors = TRUE)
 	attr(ret, "variables") <- variables
 	ret
 }
 
 
+# TODO: add theta
+# TODO: glmmTMB family
+# FIXME: family.betareg is not binomial
+#negbin(theta = .1, link = "log")$getTheta()
+#ocat(theta=1,link="identity",R=NULL)$getTheta(1)
+#ziP(theta = 1, link = "identity",b=0)
+
 family2char <-
 function(x, fam = x$family, link = x$link) {
-	if(nchar(fam) > 17L && (substr(fam, 1L, 17) == "Negative Binomial")) {
+	if(startsWith(fam, "Negative Binomial")) {
 		theta <- as.numeric(strsplit(fam, "[\\(\\)]")[[1L]][2L])
 		paste0("negative.binomial", "(", theta, ",", link, ")")
+	} else if (startsWith(fam, "Tweedie(")) {
+		paste0(substr(fam, 1L, nchar(fam) - 1L), ",link=", link, ")")
 	} else {
+		switch(fam, "scaled t" = "scat",
+			   "Beta regression" = if("putTheta" %in% names(x))
+					"betar" else "beta.regression",
+			   "zero inflated Poisson" = "ziP",
+			   "Cox PH" = "cox.ph",
+			   "Ordered Categorical" = "ocat",
+			   "Multivariate normal" = "mvn",
+			   beta = "beta_family",
+			   )
 		paste0(fam, "(", link, ")")
 	}
 }
