@@ -5,27 +5,29 @@ if(MuMIn:::.parallelPkgCheck(quiet = TRUE)) {
 	
 		library(MuMIn)
 		library(nlme)
-		data(Orthodont, package = "nlme")
 
-		# Orthodont$rand <- runif(nrow(Orthodont))
+		data(Orthodont, package = "nlme")
+		#Orthodont <- Orthodont[sample.int(nrow(Orthodont), size = 64,
+			#replace = TRUE), ]
+		Orthodont$rand1 <- runif(nrow(Orthodont))
+		Orthodont$rand2 <- runif(nrow(Orthodont))
+		clusterExport(clust, "Orthodont")
+		clusterCall(clust, "library", "nlme", character.only = TRUE)		
+
 		# fm2 <- lmer(log(distance) ~ rand*Sex*age + (1|Subject) + (1|Sex),
 		#	data = Orthodont, REML=FALSE)
-		fm2 <- lme(log(distance) ~ Sex*age, ~ 1|Subject / Sex,
+		fm2 <- lme(log(distance) ~ rand1*Sex*age + rand2, ~ 1|Subject / Sex,
 			data = Orthodont, method = "ML")
-
-		clusterExport(clust, "Orthodont")
-		clusterCall(clust, "library", "nlme", character.only = TRUE)
-
-		print(system.time(pddc <- pdredge(fm2, cluster = clust)))
-		print(system.time(pdd1 <- pdredge(fm2, cluster = FALSE)))
+		print(system.time(pdd1 <- dredge(fm2, cluster = FALSE)))
+		print(system.time(pddc <- dredge(fm2, cluster = clust)))
 		print(system.time(dd1 <- dredge(fm2)))
-		
+
 		print(pddc)
 		print(pdd1)
 		print(dd1)
 		
 		#print(all.equal(pddc, dd1))
-		ma1 <- model.avg(pdd1, beta = FALSE)
+		ma1 <- model.avg(pdd1, beta = "none")
 		ma0 <- model.avg(pddc)
 
 		if(!isTRUE(test <- all.equal(ma1$avg.model, ma0$avg.model))) {
